@@ -102,14 +102,15 @@ def _nsp_unique(child_nsmap: dict, parent_nsmap: dict) -> dict:
     return nsmap
 
 
-def _process_element(e, clean) -> Node:
+def _process_element(e, clean, literals) -> Node:
     """
     Process an lxml etree element into a Metapype node. If the clean attribute is true, then
     remove leading and trailing whitespace from the element content.
 
     Args:
         e: lxml etree element
-        clean: boolean to clean leading and trailing whitespace
+        clean: boolean to clean leading and trailing whitespace from node content
+        literals: tuple of XML elements whose content should not be altered
 
     Returns: Node
 
@@ -122,13 +123,23 @@ def _process_element(e, clean) -> Node:
 
     if clean:
         if e.text is not None:
-            # if text consists entirely of one or more spaces and/or non-breaking spaces, keep it
-            if re.search("^[ \xA0]+$", e.text):
+            if tag in literals:
                 node.content = e.text
             else:
-                node.content = None if e.text.strip() == '' else e.text.strip()
+                # if text consists entirely of one or more spaces and/or non-breaking spaces, keep it
+                if re.search("^[ \xA0]+$", e.text):
+                    node.content = e.text
+                else:
+                    node.content = None if e.text.strip() == '' else e.text.strip()
+        if e.tail is not None:
+            # if tail consists entirely of one or more spaces and/or non-breaking spaces, keep it
+            if re.search("^[ \xA0]+$", e.tail):
+                node.tail = e.tail
+            else:
+                node.tail = None if e.tail.strip() == '' else e.tail.strip()
     else:
         node.content = e.text
+        node.tail = e.tail
 
     for name, value in e.attrib.items():
         if "{" not in name:
@@ -139,7 +150,7 @@ def _process_element(e, clean) -> Node:
 
     for _ in e:
         if _.tag is not etree.Comment:
-            node.add_child(_process_element(_, clean))
+            node.add_child(_process_element(_, clean, literals))
     for child in node.children:
         child.parent = node
         if child.nsmap == node.nsmap:
@@ -230,25 +241,27 @@ def graph(node: Node, level: int = 0) -> str:
     return g
 
 
-def from_xml(xml: str, clean: bool = True, ) -> Node:
+def from_xml(xml: str, clean: bool = True, literals: tuple = ()) -> Node:
     """
     Convert an XML model into a Metapype model. If clean is true, remove leading and trailing whitespace
     from the element content.
 
     Args:
         xml: XML string to be converted
-        clean: boolean to clean leading and trailing whitespace
+        clean: boolean to clean leading and trailing whitespace from node content
+        literals: tuple of XML elements whose content should not be altered
 
     Returns: the root Node of the Metapype model
 
     """
-    root = _process_element(etree.fromstring(xml.encode("utf-8")), clean)
+    root = _process_element(etree.fromstring(xml.encode("utf-8")), clean, literals)
     return root
 
 
 def to_xml(node: Node, parent: Node = None, level: int = 0) -> str:
     xml = ""
-    indent = "  " * level
+    spacing = "  "
+    indent = spacing * level
 
     tag = f"{node.name}" if node.prefix is None else f"{node.prefix}:{node.name}"
 
@@ -257,7 +270,8 @@ def to_xml(node: Node, parent: Node = None, level: int = 0) -> str:
         attributes += " ".join([f"{k}=\"{v}\"" for k, v in node.attributes.items()])
 
     if parent is None:
-        attributes += " " + " ".join([f"xmlns:{k}=\"{v}\"" for k, v in node.nsmap.items()])
+        if len(node.nsmap) > 0:
+            attributes += " " + " ".join([f"xmlns:{k}=\"{v}\"" for k, v in node.nsmap.items()])
     elif node.nsmap != parent.nsmap:
         nsmap = _nsp_unique(node.nsmap, parent.nsmap)
         attributes += " " + " ".join([f"xmlns:{k}=\"{v}\"" for k, v in nsmap.items()])
@@ -276,6 +290,10 @@ def to_xml(node: Node, parent: Node = None, level: int = 0) -> str:
         open_tag = f"{indent}<{tag}{attributes}>\n"
         close_tag = f"{indent}</{tag}>\n"
 
+    if node.tail is not None:
+        tail = escape(node.tail)
+        close_tag += tail
+
     xml += open_tag
     for child in node.children:
         xml += to_xml(child, node, level + 1)
